package com.unis.message.app.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.message.client.NoticeFeign;
import com.unis.message.common.vo.notice.PortalNoticeVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @ClassName PortalNoticeController
 * @Description 通知公告管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "通知公告管理controller")
public class PortalNoticeController {

	@Autowired
	private NoticeFeign noticeFeign;

	@ApiOperation(value = "根据id查询通知公告", notes = "参数：通知公告id")
	@GetMapping(value = "/notice/{id}/")
	public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
		return noticeFeign.findById(id);
	}

	@ApiOperation(value = "保存通知公告信息", notes = "参数：通知公告对象PortalNoticeVO的基础信息")
	@PostMapping(value = "/notice/")
	public ResponseWrapper save(@RequestBody PortalNoticeVO vo) throws Exception {
		return noticeFeign.save(vo);
	}
	
	@ApiOperation(value = "更新or发布通知公告信息", notes = "参数：通知公告对象PortalNoticeVO的基础信息,code(0：更新，1：发布)")
	@PutMapping(value = "/notice")
	public ResponseWrapper update(@RequestBody PortalNoticeVO vo, String code) throws Exception {
		return noticeFeign.update(vo, code);
	}

	@ApiOperation(value = "删除通知公告", notes = "参数：通知公告id(可传入多个)， 操作用户id")
	@DeleteMapping(value = "/notices")
	public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
		return noticeFeign.deletes(ids, userId);
	}

	@ApiOperation(value = "管理端：查询所有通知公告", notes = "参数：PortalNoticeVO")
	@ApiImplicitParams({ @ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/noticesPage/manager")
	public ResponseWrapper findByPageManager(@RequestBody PortalNoticeVO vo, Integer page,
                                             Integer size) throws Exception {
		return noticeFeign.findByPageManager(vo, page, size);
	}
	
//	@ApiOperation(value = "当点击阅读时，保存通知公告信息阅读状态", notes = "参数：通知公告对象PortalNoticeVO")
//	@PostMapping(value = "/saveReadStatus")
//	public ResponseWrapper saveReadStatus(@RequestBody PortalNoticeUserVO vo) {
//		return ResponseWrapper.success(
//				HttpStatus.OK.value(),
//				HttpStatus.OK.getReasonPhrase(),
//				portalWebSetService.saveReadStatus(vo));
//	}
	
	@ApiOperation(value = "用户端：查询通知公告", notes = "参数：PortalNoticeVO")
	@ApiImplicitParams({ @ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/noticesPage/user")
	public ResponseWrapper findByPageUser(@RequestBody PortalNoticeVO vo, Integer page,
                                          Integer size) throws Exception {
		return noticeFeign.findByPageUser(vo, page, size);
	}
	
	@ApiOperation(value = "用户端：查询通知公告--不分页", notes = "参数：PortalNoticeVO")
	@PostMapping(value = "/notice/user")
	public ResponseWrapper findByUser(@RequestBody PortalNoticeVO vo) throws Exception {
		return noticeFeign.findByUser(vo);
	}
	
	@ApiOperation(value = "获取用户通知公告数量", notes = "参数：当前登陆用户userId")
	@GetMapping(value = "/noticeNum/{id}/")
	public ResponseWrapper getNoticeNum(@PathVariable("id") String id) throws Exception {
		return noticeFeign.findById(id);
	}
}
